OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotky",
    "Your memories under your control" : "Vaše vzpomínky pod vaší kontrolou",
    "All media" : "Veškerá média",
    "Videos" : "Videa",
    "Albums" : "Alba",
    "People" : "Lidé",
    "Folders" : "Složky",
    "Favorites" : "Oblíbené",
    "On this day" : "V tento den",
    "Shared with you" : "Sdíleno s vámi",
    "Tags" : "Štítky",
    "Locations" : "Umístění",
    "Photos settings" : "Nastavení pro Fotky",
    "_%n item_::_%n photos and videos_" : ["%n položka","%n fotky a videa","%n fotek a videí","%n fotky a videa"],
    "Name of the album" : "Název alba",
    "Location of the album" : "Umístění alba",
    "Go back to the previous view." : "Jít zpět na předchozí pohled.",
    "Back" : "Zpět",
    "Go to the add collaborators view." : "Jít na pohled přidání spolupracujících.",
    "Add collaborators" : "Přidat spolupracující",
    "Save." : "Uložit.",
    "Create the album." : "Vytvořit album.",
    "Save" : "Uložit",
    "Create album" : "Vytvořit album",
    "Back to the new album form." : "Zpět na formulář pro nové album.",
    "Add to Album" : "Přidat do alba",
    "Create a new album." : "Vytvořit nové album.",
    "Create new album" : "Vytvořit nové album",
    "New album" : "Nové album",
    "_Share with %n user_::_Share with %n users_" : ["Nasdílet %n uživateli","Nasdílet %n uživatelům","Nasdílet %n uživatelům","Nasdílet %n uživatelům"],
    "Add users who can edit your album" : "Přidat uživatele, kteří mohou upravovat vaše album",
    "Share this album via link" : "Nasdílet toto album prostřednictvím odkazu",
    "Search users, email or Federated Cloud ID" : "Hledat uživatele, e-maily nebo identif. v rámci federovaného cloudu",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Select image {imageName}" : "Vybrat obrázek {imageName}",
    "The file is in the favorites" : "Soubor je v oblíbených",
    "Open the full size \"{name}\" image" : "Otevřít obrázek „{name}“ v plné velikosti",
    "Upload from computer" : "Nahrát z počítače",
    "Add to {destination}" : "Přidat do {destination}",
    "Open the \"{name}\" sub-directory" : "Otevřít podsložku „{name}“",
    "Back to {folder}" : "Zpět do {folder}",
    "Share this folder" : "Sdílet tuto složku",
    "_{years} year ago_::_{years} years ago_" : ["Před {years} rokem","Před {years} roky","Před {years} lety","Před {years} roky"],
    "Enable squared photos view" : "Zapnout čtvercové zobrazení fotek",
    "Default Photos upload and Albums location" : "Výchozí umístění nahrávání fotek a alb",
    "Select the default location for your media" : "Vyberte výchozí umístění pro vaše média",
    "Invalid location selected" : "Vybráno neplatné umístění",
    "View" : "Zobrazit",
    "Photos directory" : "Složka pro fotky",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "This album does not exist" : "Toto album neexistuje",
    "An error occurred" : "Došlo k chybě",
    "Add photos to this album" : "Přidat fotky do tohoto alba",
    "Share this album" : "Nasdílet toto albu",
    "Edit album details" : "Upravit podrobnosti o albu",
    "Download all files in album" : "Stáhnout veškeré soubory v albu",
    "Download selection" : "Výběr stahování",
    "Download selected files" : "Stáhnout si označené soubory",
    "Mark selection as favorite" : "Označit vybrané jako oblíbené",
    "Favorite" : "Přidat do oblíbených",
    "Remove selection from favorites" : "Odebrat vybrané z oblíbených",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Delete album" : "Smazat album",
    "Add photos to the album" : "Přidat fotky do alba",
    "Share the album" : "Nasdílet album",
    "_Remove item from album_::_Remove selection from album_" : ["Odebrat položku z alba","Odebrat vybrané z alba","Odebrat vybrané z alba","Odebrat vybrané z alba"],
    "Create a new album" : "Vytvořit nové album",
    "This person could not be found" : "Tuto osobu se nepodařilo nalézt",
    "Rename person" : "Přejmenovat osobu",
    "Merge with different person" : "Sloučit s jinou osobou",
    "Download selected photos" : "Stáhnout si označené fotky",
    "Remove person" : "Odebrat osobu",
    "Name of this person" : "Pojmenovat tuto osobu",
    "Merge person" : "Sloučit osobu",
    "_Remove photo from person_::_Remove photos from person_" : ["Odebrat fotku z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby"],
    "This might take some time depending on the size of your photo library." : "Toto může zabrat nějakou dobu v závislosti na velikosti vaší knihovny fotek.",
    "Recognized people will show up here" : "Rozpoznaní lidé se zobrazí zde",
    "This folder does not exist" : "Tato složka neexistuje",
    "Loading folders …" : "Načítání složek…",
    "No photos in here" : "Tady nejsou žádné fotky",
    "Back to tags overview" : "Zpět na přehled štítků",
    "No tags yet" : "Zatím žádné štítky",
    "Photos with tags will show up here" : "Fotky opatřené štítky se objeví zde",
    "Popular tags" : "Oblíbené štítky",
    "Add" : "Přidat",
    "Upload media" : "Nahrát médium",
    "Add selection to an album" : "Přidat do alba výběr",
    "Add to album" : "Přidat do alba",
    "Download" : "Stáhnout",
    "Delete selection" : "Smazat výběr",
    "Delete" : "Smazat",
    "{startDate} to {endDate}" : "{startDate} až {endDate}",
    "Failed to fetch albums list." : "Nepodařilo se získat seznam alb.",
    "Failed to fetch faces list." : "Nepodařilo se získat seznam obličejů.",
    "Tagged photos" : "Oštítkované fotky",
    "Failed to favorite {fileName}." : "Nepodařilo se přidat {fileName} do oblíbených.",
    "Failed to create {albumName}." : "Nepodařilo se vytvořit {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Nepodařilo přejmenovat {currentAlbumName} to {newAlbumName}.",
    "Failed to update location of {albumName} to {newLocation}." : "Nepodařilo se aktualizovat umístění {albumName} to {newLocation}.",
    "Failed to delete {albumName}." : "Nepodařilo se smazat {albumName}.",
    "Failed to rename {oldName} to {faceName}." : "Nepodařilo se přejmenovat {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nepodařilo se smazat {faceName}.",
    "Your photos" : "Vaše fotky",
    "Your videos" : "Vaše videa",
    "Your folders" : "Vaše složky",
    "Settings" : "Nastavení"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
